==> litecoin-0.13.2.tar.gz: litecoin-0.13.2/src/qt/locale/bitcoin_bg_BG.ts <==
<TS language="bg_BG" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Клик с десен бутон на мишката за промяна на адрес или етикет</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Създай нов адрес</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Нов</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Копирай текущо избрания адрес към клипборда</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Копирай</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Затвори</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Изтрий текущо избрания адрес от листа</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Изнеси данните в избрания раздел към файл</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>Изнеси</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Изтрий</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Диалог за пропуск</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Въведи парола</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Нова парола</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Повтори парола</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Мрежова маска</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Блокиран до</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Подпиши съобщение...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Синхронизиране с мрежата...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>Преглед</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Възел</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Покажи общ преглед на портфейла</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>Транзакции</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Разгледай история на транзакциите</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Излез от приложението</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>За %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Покажи информация за %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Относно Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Покажи информация отностно Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Промени конфигурации за %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Криптирай портфейл</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Направи резервно копие на портфейла...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Промени паролата...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>Адреси за пращане...</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>Адреси за получаване...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Отвори URI</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Повторно индексиране на блоковете на диска...</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Bitcoin Core</source>
        <translation>Биткойн ядро</translation>
    </message>
    </context>
</TS>

==> litecoin-0.15.0.tar.gz: litecoin-0.15.0/src/qt/locale/bitcoin_bg_BG.ts <==
<TS language="bg_BG" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Клик с десен бутон на мишката за промяна на адрес или етикет</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Създай нов адрес</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Нов</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Копирай текущо избрания адрес към клипборда</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Копирай</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>Затвори</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Изтрий текущо избрания адрес от листа</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Изнеси данните в избрания раздел към файл</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>Изнеси</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Изтрий</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Избери адреса на който да пратиш монети</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Избери адреса на който да получиш монети</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>Избери</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Адрес за пращане</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Адрес за получаване</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Тези са вашите Litecoin адреси за изпращане на монети. Винаги проверявайте количеството и получаващия адрес преди изпращане. </translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Това са вашите Litecoin адреси за получаване на монети. Препоръчително е да ползвате нов адрес на всяка транзакция.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>Копирай адрес</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Копирай етикет</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Редактирай</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Изнеси лист с адреси</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Comma separated file (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Изнасянето се провали</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Получи се грешка при запазването на листа с адреси към %1. Моля опитайте пак.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Етикет</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Диалог за пропуск</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Въведи парола</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Нова парола</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Повтори парола</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Криптирай портфейл</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Тази операция изисква вашата парола на портфейла за отключването на портфейла.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Отключи портфейла</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Тази операция изисква вашата парола на портфейла за декриптирането на портфейла.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Декриптирай портфейл</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Промени парола</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Потвърди криптирането на порфейла</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Мрежова маска</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Блокиран до</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Подпиши съобщение...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Синхронизиране с мрежата...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>Преглед</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>Възел</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Покажи общ преглед на портфейла</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>Транзакции</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Разгледай история на транзакциите</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Излез от приложението</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>За %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Покажи информация за %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Относно Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Покажи информация отностно Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Промени конфигурации за %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>Криптирай портфейл</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>Направи резервно копие на портфейла...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>Промени паролата...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>Адреси за пращане...</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>Адреси за получаване...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Отвори URI</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Повторно индексиране на блоковете на диска...</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Етикет</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Етикет</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Етикет</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(без етикет)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Comma separated file (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Етикет</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Изнасянето се провали</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>Изнеси</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Изнеси данните в избрания раздел към файл</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Litecoin Core</source>
        <translation>Litecoin ядро</translation>
    </message>
    </context>
</TS>
